#!/usr/bin/env python
# coding: utf-8

# In[1]:


import finesse.virgo


# # Creating a Virgo Model
# 
# The Virgo model in Finesse 3 uses two main katscript files: the common Virgo file which contains the main interferometer definition, and an additional katscript file which contains extra variables, dofs, and detectors used in the pre-tuning process.
# 
# There are several ways to create a Virgo model depending upon which input is provided:
# 
# 1. **Default**: Providing no input parses the default files.
# 2. **File**: if passing a file, only that file will be parsed. It is assumed to be a tuned file (with the locks). If providing only a modified common file, the additional katscript file can be parsed explicitly using the `parse_additional_katscript` flag.
# 3. **Directory**: Passing a directory will parse all kat files within the directory.

# For this notebook, so we have some files to work with, we'll start by creating local copies of the katfiles. See `examples/utilities.ipynb` for additional information and examples.

# In[2]:


# copy katfiles into a local directory
finesse.virgo.copy_input_files('custom_katscript')


# ## 1. Providing no input files
# 
# Providing no input will parse the current common file and additional katscript found within the `katscript` directory.
# 
# Caution: This is quick and dirty. The parameters contained within the common file are expected to change over time, so using this option will potentially produce different results depending on when it is used. Use a local file to increase the reliability of your code.

# In[3]:


# create a Virgo model using the current common files
virgo = finesse.virgo.Virgo()

# pretune and save to use later in the notebook
virgo.make()
virgo.model.unparse_file('custom_katscript/virgo_pretuned.kat.skip')


# ## 2. Providing an input file
# 
# Two types of files are accepted: a pre-tuned/unparsed file and a modified common file.
# 
# 1. **Pre-tuned file**: (often generated by unparsing a tuned model) the file is simply parsed but will also try to parse the locks if they have not already been added.
# 
# 2. **Common file**: the additional katscript will still need to be parsed, so `parse_additional_katscript=True` needs to be provided before the model is ready to be tuned.

# In[4]:


# create a Virgo model using pretuned file from previous example
virgo = finesse.virgo.Virgo('custom_katscript/virgo_pretuned.kat.skip')


# In[5]:


# create a Virgo model using a modified common file
virgo = finesse.virgo.Virgo(
    'custom_katscript/00_virgo_common_file.kat', 
    parse_additional_katscript=True
)


# ## 3. Providing a directory
# 
# It is also an option to provide an entire directory. Using this option will parse all katfiles found within the directory. This option pairs well when using `copy_input_files`.

# In[6]:


# create Virgo using the directory created earlier in the notebook
virgo = finesse.virgo.Virgo('custom_katscript')

